@@ -3,7 +3,7 @@ package Evo::EA::Graph;
 sub new {
 	my ($class) = @_;
 
-	my $self = {};
+	my $self = { node => GraphNode->new( () ), };
 
 	$class = ref($class) || $class;
 
